@@ -1,11 +1,12 @@
 #!/usr/bin/env python3
 
 import argparse
-import markups
 import sys
 
+import markups
 
-def export_file(args):
+
+def export_file(args: argparse.Namespace) -> None:
     markup = markups.get_markup_for_file_name(args.input_file)
     with open(args.input_file) as input:
         text = input.read()
